@@ -3,7 +3,8 @@ package Testmask1;
 use strict;
 use warnings;
 
-use base qw(Bitmask::Data);
+use parent qw(Bitmask::Data);
+use Math::BigInt;
 
 __PACKAGE__->bitmask_lazyinit(1);
 __PACKAGE__->init(
@@ -12,8 +13,10 @@ __PACKAGE__->init(
     'value3' => 0x8000, #16
     'value4' => 0x4, #3
     'value5', # 5
-    'value6', # 6 
+    'value6' => '0b0100000', # 6 
     'value7' => 8, #4
+    'value8' => Math::BigInt->new('128'),
+    'value9' => "\1\0\0\0\0\0\0\0\0",
 );
 
 1;
\ No newline at end of file
