@@ -1,8 +1,7 @@
 package Testmask5;
 use strict;
 use warnings;
-use base qw(Bitmask::Data);
-
+use parent qw(Bitmask::Data);
 
 __PACKAGE__->bitmask_length(5);
 __PACKAGE__->bitmask_lazyinit(1);
